@@ -1,5 +1,3 @@
-import urllib
-
 from django.contrib.auth.models import User
 
 from funkymetrics.tasks import send_event
@@ -28,11 +26,15 @@ def record_event(request_or_user, action, props=None):
         if hasattr(request_or_user, 'COOKIES') is not None:
             identity = request_or_user.COOKIES.get('km_ai', '')
 
-    # URL encode properties
+    # Encode as UTF-8
+    _props = None
     if props is not None:
+        _props = {}
         for key, val in props.items():
-            props[key] = urllib.quote_plus(val)
+            _key = unicode(key).encode('utf-8')
+            _val = unicode(val).encode('utf-8')
+            _props[_key] = _val
 
     # Queue task
     if identity != '':
-        send_event.delay(identity, action, props)
+        send_event.delay(identity, action, _props)
